-- 用户表
CREATE TABLE IF NOT EXISTS `user` (
  `id` bigint NOT NULL AUTO_INCREMENT COMMENT '用户ID',
  `username` varchar(50) NOT NULL COMMENT '用户名',
  `password` varchar(100) NOT NULL COMMENT '密码',
  `nickname` varchar(50) DEFAULT NULL COMMENT '昵称',
  `avatar` varchar(255) DEFAULT NULL COMMENT '头像URL',
  `email` varchar(100) DEFAULT NULL COMMENT '邮箱',
  `phone` varchar(20) DEFAULT NULL COMMENT '手机号',
  `gender` tinyint DEFAULT '0' COMMENT '性别: 0-未知, 1-男, 2-女',
  `bio` varchar(255) DEFAULT NULL COMMENT '个人简介',
  `created_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `last_login_time` datetime DEFAULT NULL COMMENT '最后登录时间',
  `status` tinyint NOT NULL DEFAULT '1' COMMENT '状态: 0-禁用, 1-正常',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_username` (`username`),
  UNIQUE KEY `uk_email` (`email`),
  UNIQUE KEY `uk_phone` (`phone`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci COMMENT='用户表';


CREATE TABLE IF NOT EXISTS `sys_log` (
                           `id` bigint NOT NULL AUTO_INCREMENT COMMENT '日志ID',
                           `user_id` bigint DEFAULT NULL COMMENT '用户ID',
                           `username` varchar(50) DEFAULT NULL COMMENT '用户名',
                           `operation` varchar(50) DEFAULT NULL COMMENT '操作',
                           `method` varchar(200) DEFAULT NULL COMMENT '方法名',
                           `params` varchar(2000) DEFAULT NULL COMMENT '参数',
                           `ip` varchar(64) DEFAULT NULL COMMENT 'IP地址',
                           `location` varchar(255) DEFAULT NULL COMMENT '操作地点',
                           `create_time` datetime DEFAULT NULL COMMENT '创建时间',
                           `time_consuming` bigint DEFAULT NULL COMMENT '耗时(毫秒)',
                           `user_agent` varchar(500) DEFAULT NULL COMMENT '用户代理',
                           `status` tinyint DEFAULT NULL COMMENT '状态(1-成功,0-失败)',
                           `error_msg` varchar(2000) DEFAULT NULL COMMENT '错误信息',
                           PRIMARY KEY (`id`),
                           KEY `idx_user_id` (`user_id`),
                           KEY `idx_create_time` (`create_time`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci COMMENT='系统操作日志';



CREATE TABLE `video` (
                         `id` bigint NOT NULL AUTO_INCREMENT COMMENT '视频ID',
                         `title` varchar(100) NOT NULL COMMENT '视频标题',
                         `description` text COMMENT '视频描述',
                         `url` varchar(255) NOT NULL COMMENT '视频URL',
                         `cover_url` varchar(255) DEFAULT NULL COMMENT '封面图URL',
                         `duration` bigint DEFAULT NULL COMMENT '视频时长（秒）',
                         `size` bigint NOT NULL COMMENT '文件大小（字节）',
                         `status` varchar(20) NOT NULL COMMENT '状态：DRAFT-草稿，PUBLISHED-已发布，DELETED-已删除',
                         `user_id` bigint NOT NULL COMMENT '上传用户ID',
                         `username` varchar(50) DEFAULT NULL COMMENT '上传用户名',
                         `created_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                         `updated_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                         `view_count` int NOT NULL DEFAULT '0' COMMENT '观看次数',
                         `like_count` int NOT NULL DEFAULT '0' COMMENT '点赞次数',
                         `tags` varchar(255) DEFAULT NULL COMMENT '标签，逗号分隔',
                         PRIMARY KEY (`id`),
                         KEY `idx_user_id` (`user_id`),
                         KEY `idx_created_time` (`created_time`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci COMMENT='视频表';